@@ -31,11 +31,16 @@
  */
 
 #define _MAJ 1
-#define _MIN 2
+#define _MIN 3
 #define _SUB_MIN 0
 #define _BETA 0
 #define _RC 0
 #define WEBSITE "https://www.aircrack-ng.org"
 
-extern char * getVersion(char * progname, int maj, int min, int submin, const
-       char * rev, int beta, int rc);
+extern char *getVersion(const char *progname,
+						const unsigned int maj,
+						const unsigned int min,
+						const unsigned int submin,
+						const char *rev,
+						const unsigned int beta,
+						const unsigned int rc);
